@@ -83,7 +83,7 @@ var searchData=
   ['ssh_5fchannel_5fis_5feof',['ssh_channel_is_eof',['../group__libssh__channel.html#gab535264029443d77214c0615a0788b0a',1,'ssh_channel_is_eof(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#gab535264029443d77214c0615a0788b0a',1,'ssh_channel_is_eof(ssh_channel channel):&#160;channels.c']]],
   ['ssh_5fchannel_5fis_5fopen',['ssh_channel_is_open',['../group__libssh__channel.html#gaaafcda943c96ddb91e5c28c0bdee7045',1,'ssh_channel_is_open(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#gaaafcda943c96ddb91e5c28c0bdee7045',1,'ssh_channel_is_open(ssh_channel channel):&#160;channels.c']]],
   ['ssh_5fchannel_5flisten_5fforward',['ssh_channel_listen_forward',['../group__libssh__channel.html#ga758cda957227751870c8772df46e5b39',1,'ssh_channel_listen_forward(ssh_session session, const char *address, int port, int *bound_port):&#160;channels.c'],['../group__libssh__channel.html#ga758cda957227751870c8772df46e5b39',1,'ssh_channel_listen_forward(ssh_session session, const char *address, int port, int *bound_port):&#160;channels.c']]],
-  ['ssh_5fchannel_5fnew',['ssh_channel_new',['../group__libssh__channel.html#gada8ccda7bf65165fe145d3096a252dcc',1,'ssh_channel_new(ssh_session session):&#160;channels.c'],['../group__libssh__channel.html#gada8ccda7bf65165fe145d3096a252dcc',1,'ssh_channel_new(ssh_session session):&#160;channels.c'],['../group__libssh__channel.html#gada8ccda7bf65165fe145d3096a252dcc',1,'ssh_channel_new(ssh_session session):&#160;channels.c']]],
+  ['ssh_5fchannel_5fnew',['ssh_channel_new',['../group__libssh__channel.html#gada8ccda7bf65165fe145d3096a252dcc',1,'ssh_channel_new(ssh_session session):&#160;channels.c'],['../group__libssh__channel.html#gada8ccda7bf65165fe145d3096a252dcc',1,'ssh_channel_new(ssh_session session):&#160;channels.c']]],
   ['ssh_5fchannel_5fopen_5fauth_5fagent',['ssh_channel_open_auth_agent',['../group__libssh__channel.html#ga6c4d4f5436dd5be58973606c6bcd8bb4',1,'ssh_channel_open_auth_agent(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#ga6c4d4f5436dd5be58973606c6bcd8bb4',1,'ssh_channel_open_auth_agent(ssh_channel channel):&#160;channels.c']]],
   ['ssh_5fchannel_5fopen_5fforward',['ssh_channel_open_forward',['../group__libssh__channel.html#gae86b0704a1f2bdebb268b55567f7f47b',1,'ssh_channel_open_forward(ssh_channel channel, const char *remotehost, int remoteport, const char *sourcehost, int localport):&#160;channels.c'],['../group__libssh__channel.html#gae86b0704a1f2bdebb268b55567f7f47b',1,'ssh_channel_open_forward(ssh_channel channel, const char *remotehost, int remoteport, const char *sourcehost, int localport):&#160;channels.c']]],
   ['ssh_5fchannel_5fopen_5fsession',['ssh_channel_open_session',['../group__libssh__channel.html#gaf051dd30d75bf6dc45d1a5088cf970bd',1,'ssh_channel_open_session(ssh_channel channel):&#160;channels.c'],['../group__libssh__channel.html#gaf051dd30d75bf6dc45d1a5088cf970bd',1,'ssh_channel_open_session(ssh_channel channel):&#160;channels.c']]],
@@ -251,6 +251,7 @@ var searchData=
   ['ssh_5fserver_5finit_5fkex',['ssh_server_init_kex',['../group__libssh__server.html#ga2594833b600c8461fbe26d16e99a211b',1,'server.c']]],
   ['ssh_5fsession_5fexport_5fknown_5fhosts_5fentry',['ssh_session_export_known_hosts_entry',['../group__libssh__session.html#ga519c3985c8803c67d24ce9f937e3da9a',1,'ssh_session_export_known_hosts_entry(ssh_session session, char **pentry_string):&#160;knownhosts.c'],['../group__libssh__session.html#ga519c3985c8803c67d24ce9f937e3da9a',1,'ssh_session_export_known_hosts_entry(ssh_session session, char **pentry_string):&#160;knownhosts.c']]],
   ['ssh_5fsession_5fget_5fknown_5fhosts_5fentry',['ssh_session_get_known_hosts_entry',['../group__libssh__session.html#ga874d3246c9c9bfc7040302e10650bce8',1,'ssh_session_get_known_hosts_entry(ssh_session session, struct ssh_knownhosts_entry **pentry):&#160;knownhosts.c'],['../group__libssh__session.html#ga874d3246c9c9bfc7040302e10650bce8',1,'ssh_session_get_known_hosts_entry(ssh_session session, struct ssh_knownhosts_entry **pentry):&#160;knownhosts.c']]],
+  ['ssh_5fsession_5fget_5fknown_5fhosts_5fentry_5ffile',['ssh_session_get_known_hosts_entry_file',['../group__libssh__session.html#gae484a2e6dac6c5738db62c3ba602f118',1,'ssh_session_get_known_hosts_entry_file(ssh_session session, const char *filename, struct ssh_knownhosts_entry **pentry):&#160;knownhosts.c'],['../group__libssh__session.html#gae484a2e6dac6c5738db62c3ba602f118',1,'ssh_session_get_known_hosts_entry_file(ssh_session session, const char *filename, struct ssh_knownhosts_entry **pentry):&#160;knownhosts.c']]],
   ['ssh_5fsession_5fhas_5fknown_5fhosts_5fentry',['ssh_session_has_known_hosts_entry',['../group__libssh__session.html#gaffea2fa1210919f833a081739734476d',1,'ssh_session_has_known_hosts_entry(ssh_session session):&#160;knownhosts.c'],['../group__libssh__session.html#gaffea2fa1210919f833a081739734476d',1,'ssh_session_has_known_hosts_entry(ssh_session session):&#160;knownhosts.c']]],
   ['ssh_5fsession_5fis_5fknown_5fserver',['ssh_session_is_known_server',['../group__libssh__session.html#gacbc5d04fe66beee863a0c61a93fdf765',1,'ssh_session_is_known_server(ssh_session session):&#160;knownhosts.c'],['../group__libssh__session.html#gacbc5d04fe66beee863a0c61a93fdf765',1,'ssh_session_is_known_server(ssh_session session):&#160;knownhosts.c']]],
   ['ssh_5fsession_5fupdate_5fknown_5fhosts',['ssh_session_update_known_hosts',['../group__libssh__session.html#ga958fdd1aedcd85a5c496c0aa22362d34',1,'ssh_session_update_known_hosts(ssh_session session):&#160;knownhosts.c'],['../group__libssh__session.html#ga958fdd1aedcd85a5c496c0aa22362d34',1,'ssh_session_update_known_hosts(ssh_session session):&#160;knownhosts.c']]],
